/*
Copyright (C) 2007 Google Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

/**
 * @fileoverview Commonly used string functions
 */
 
/**
 * Trims whitespace from the beginning and end of the string
 * @return returns the trimmed version of the string
 */
String.prototype.trim = function() {
  var str = this.replace(/^\s+/g, "");  // strip leading
  return str.replace(/\s+$/g, "");  // strip trailing
};

/**
 * Placeholder substitution
 * @param {String} s The string containing a placeholder
 * @param {String} ph The placeholder, e.g. "NUMBER"
 * @param {String} replacement Replacement text
 * @return returns string with replaced text
 */
function Utils_substitutePH(s, ph, replacement) {
  return s.replace("[![" + ph + "]!]", replacement);
}
